@@ -11,9 +11,9 @@ BinaryLogBiplotGDRecursive <- function(X, freq = matrix(1, nrow(X), 1),  dim = 2
   r=dim
   # Fitting the constants
   b0=matrix(0,nrow=p, ncol=1)
-  for (j in 1:p)
-    b0[j]=RidgeBinaryLogistic(y=X[,j], matrix(1,n,1), penalization = penalization)$beta
-  B=b0
+  b0 <- optim(par=b0, fn=JLogBiplotRegRecb0, gr=grLogBiplotRegBRecb0, method=OptimMethod, X=X)$par
+
+  B = matrix(b0, ncol=1)
   A=matrix(1,nrow=n, ncol=1)
   H=sigmoide(A %*% t(B))
   J=sum(-1*X*log(H)-(1-X)*log(1-H), na.rm = TRUE)/2  + penalization*sum(B[,-1]^2, na.rm = TRUE)/2
