@@ -1,3 +1,24 @@
+# Cost and gradients for the constant
+JLogBiplotRegRecb0 <- function(par, X) {# Cost to estimate d
+  I=dim(X)[1]
+  L=dim(X)[2]
+  A=matrix(1,nrow=I, ncol=1)
+  H=sigmoide(A%*%t(par))
+  J=sum(-1*X*log(H)-(1-X)*log(1-H), na.rm = TRUE)/2
+  return(J)
+}
+
+grLogBiplotRegBRecb0 <- function(par, X) { ## Gradient to estimate B
+  I=dim(X)[1]
+  L=dim(X)[2]
+  E=matrix(1,nrow=I, ncol=1)
+  H=sigmoide(E%*%t(par))
+  grad=t(H-X)%*%E
+  return(grad)
+}
+
+
+
 JLogBiplotRegRec <- function(par, X, r, lambda) {
   n=dim(X)[1]
   p=dim(X)[2]
