@@ -1,6 +1,6 @@
 OrdVarBiplot <- function(bi1, bi2,threshold, xmin = -3, xmax = 3, ymin = -3, ymax = 3, label = "Point", mode = "a",  
                          CexPoint = 0.8, PchPoint = 1, Color = "green", 
-                           tl = 0.03, textpos=1, CexScale=0.5, ...){
+                           tl = 0.03, textpos=1, CexScale=0.5, TypeLabs=1, ...){
 
   b1 = bi1/(bi1^2 + bi2^2)
   b2 = bi2/(bi1^2 + bi2^2)
@@ -66,10 +66,9 @@ OrdVarBiplot <- function(bi1, bi2,threshold, xmin = -3, xmax = 3, ymin = -3, yma
     c2 = final[2]
   }
   
-  
   if (mode == "s") {
     lines(rbind(ini, final), col = Color, lwd = 1, lty = 1, ...)
-    OrCoor=OrdVarCoordinates(tr=threshold, c(bi1,bi2), plotresponse=F)
+    OrCoor=OrdVarCoordinates(tr=threshold, c(bi1,bi2), plotresponse=F, TypeLabs=TypeLabs)
     c1 = final[1]
     c2 = final[2]
     ang = atan(bi2/bi1) * 180/pi
@@ -84,15 +83,12 @@ OrdVarBiplot <- function(bi1, bi2,threshold, xmin = -3, xmax = 3, ymin = -3, yma
         text(Mn[i, 1], Mn[i, 2], OrCoor$labels[i], pos = 1, offset = 0.2, cex = CexScale, srt = ang, col = Color, ...)
       }
     }
-    
   }
 
-  
   if ((b1 < 0) & (textpos==1)) textpos=3
   if ((b1 < 0) & (textpos==2)) textpos=4  
   if ((b1 < 0) & (textpos==3)) textpos=1
   if ((b1 < 0) & (textpos==4)) textpos=2
 
   text(c1, c2, label, cex = CexPoint, pos = textpos , offset = 0.3, srt = ang, col = Color, ...)
-
 }
\ No newline at end of file
