@@ -8,12 +8,14 @@ RidgeBinaryLogistic <- function(y, X=NULL, data=NULL, freq = NULL, tolerance = 1
                                 RidgePlot=FALSE, MinLambda=0, MaxLambda=2, StepLambda=0.1) {
   # Fits a Binary Logistic Regression using a Ridge penalization
   clasey=class(y)
+
   if (clasey=="formula"){
     X=model.matrix(y, data=data)
     y=model.frame(y, data=data)[1]
     cte=FALSE
   }
   
+
   name=colnames(y)
 
   if (is.factor(y[[1]])){
@@ -24,6 +26,8 @@ RidgeBinaryLogistic <- function(y, X=NULL, data=NULL, freq = NULL, tolerance = 1
    else y=y[,1]
   }
   
+  
+  
   n=dim(X)[1]
   if (is.numeric(y)) {y= as.matrix(y)}
   if (is.matrix(X) & cte) X=cbind(rep(1,n),X)
@@ -35,16 +39,20 @@ RidgeBinaryLogistic <- function(y, X=NULL, data=NULL, freq = NULL, tolerance = 1
   
   
   X=as.matrix(X)
+  y=as.matrix(y, nrow=n)
   
   n <- dim(X)[1]
   m <- dim(X)[2]
   
   if (is.null(freq)) 
     freq = matrix(1, n, 1)
+  
+  
+  
   model = list()
   null = list()
   # Null Model
-  null$beta = RidgeBinaryLogisticFit(y, matrix(1,n,1), freq, tolerance = tolerance, maxiter = maxiter, penalization = penalization)
+  null$beta = RidgeBinaryLogisticFit(y, xd= matrix(1,n,1), freq=freq, tolerance = tolerance, maxiter = maxiter, penalization = penalization)
   null$linterm = matrix(1,n,1) %*% null$beta
   null$fitted = exp(null$linterm)/(1 + exp(null$linterm))
   null$Deviance = -2 * sum(y * log(null$fitted)*freq + (1 - y) * log(1 - null$fitted)*freq)
@@ -110,6 +118,7 @@ RidgeBinaryLogistic <- function(y, X=NULL, data=NULL, freq = NULL, tolerance = 1
 
   }
   
+  model$bootstrap=FALSE
   if (bootstrap){
     model$bootstrap=TRUE
     betas=matrix(0, nmB, m)
