@@ -8,7 +8,7 @@ plot.Binary.Logistic.Biplot <- function(x, F1 = 1, F2 = 2, ShowAxis=FALSE, margi
                                         PchRows = NULL, PchCols = NULL, PlotClus = FALSE, TypeClus = "ch", 
                                         ClustConf=1,  Significant=TRUE, alpha=0.05, Bonferroni=TRUE, 
                                         PlotSupVars = TRUE, AbbreviateLabels = FALSE, MainTitle =TRUE, 
-                                        Title = NULL, RemoveXYlabs=FALSE, CenterCex=1.5, ...) 
+                                        Title = NULL, RemoveXYlabs=FALSE, CenterCex=1.5, CexScale=0.5, ...) 
   {
   
   
@@ -136,19 +136,6 @@ plot.Binary.Logistic.Biplot <- function(x, F1 = 1, F2 = 2, ShowAxis=FALSE, margi
   
   if (ShowBox) rect(xmin, ymin, xmax, ymax)
   
-  if (PlotClus) {
-    RowColors=PlotBiplotClusters(a, x$Clusters, TypeClus = "ch", ClusterColors = x$ClusterColors, ClusterNames=x$ClusterNames, centers = TRUE, ClustConf=ClustConf, ...)
-  }
-
-  if (PlotInd){
-    for (i in 1:n)
-      if (WhatRows[i]){
-        points(a[i, 1], a[i, 2], col = RowColors[i], cex=RowCex[i], pch = PchRows, ...)
-        if (LabelRows)
-        text(a[i, 1], a[i, 2], labels = RowLabels[i], col = RowColors[i], pos=1, cex=RowCex[i], ...)
-      }
-  }
-  
 
   if (PlotVars){
     for (i in 1:p){
@@ -156,7 +143,7 @@ plot.Binary.Logistic.Biplot <- function(x, F1 = 1, F2 = 2, ShowAxis=FALSE, margi
         PlotBinaryVar(b0=x$ColumnParameters[i,1], bi1=x$ColumnParameters[i,F1+1],
                       bi2=x$ColumnParameters[i,F2+1], xmin=xmin, xmax=xmax, ymin=ymin, 
                       ymax=ymax, mode=Mode, Color = ColColors[i], label=ColLabels[i], 
-                      tl=TickLength, CexPoint=ColCex[i], CenterCex=CenterCex)
+                      tl=TickLength, CexPoint=ColCex[i], CenterCex=CenterCex, CexScale=CexScale )
       }
     }
   }
@@ -192,6 +179,19 @@ plot.Binary.Logistic.Biplot <- function(x, F1 = 1, F2 = 2, ShowAxis=FALSE, margi
   
   if (PlotSupVars) 
     plot.Supplementary.Variables(x, F1=F1, F2=F2, xmin = xmin, xmax = xmax, ymin = ymin, ymax = ymax, mode=Mode, ColorSupContVars="blue")
+  
+  if (PlotClus) {
+    RowColors=PlotBiplotClusters(a, x$Clusters, TypeClus = "ch", ClusterColors = x$ClusterColors, ClusterNames=x$ClusterNames, centers = TRUE, ClustConf=ClustConf, ...)
+  }
+  
+  if (PlotInd){
+    for (i in 1:n)
+      if (WhatRows[i]){
+        points(a[i, 1], a[i, 2], col = RowColors[i], cex=RowCex[i], pch = PchRows, ...)
+        if (LabelRows)
+          text(a[i, 1], a[i, 2], labels = RowLabels[i], col = RowColors[i], pos=1, cex=RowCex[i], ...)
+      }
+  }
 
 # par(op)
 }
