@@ -90,7 +90,7 @@ plot.ContinuousBiplot <- function(x, A1 = 1, A2 = 2, ShowAxis = FALSE, margin =
   if (is.null(PchInd)) 
     PchInd = rep(1,n)
   else if (length(PchInd == 1)) 
-    PchInd = rep(PchInd, p)
+    PchInd = rep(PchInd, n)
   
   if (is.null(PchVar)) 
     PchVar = rep(16, p)
@@ -214,6 +214,18 @@ plot.ContinuousBiplot <- function(x, A1 = 1, A2 = 2, ShowAxis = FALSE, margin =
   }
   
 
+  if (PlotInd) 
+    for (i in 1:n)
+      if (WhatInds[i]){
+        points(A[i, 1], A[i, 2], col = ColorInd[i], cex=CexInd[i], pch = PchInd[i], ...)
+      }
+  
+  if (LabelInd)
+    for (i in 1:n)
+      if (WhatInds[i])
+        if (SmartLabels) 
+          textsmart(cbind(A[i, 1], A[i, 2]), CexPoints = CexInd[i], ColorPoints = ColorInd[i], ...)
+  else text(A[i, 1], A[i, 2], IndLabels[i], cex = CexInd[i], col = ColorInd[i], pos = LabelPos, ...)
   
   
   if (PlotVars) {
@@ -291,18 +303,7 @@ plot.ContinuousBiplot <- function(x, A1 = 1, A2 = 2, ShowAxis = FALSE, margin =
                                  ModeSupOrdVars=ModeSupOrdVars, WhatSupBinVars=WhatSupBinVars, CexScale=CexScale)
  
   
-  if (PlotInd) 
-    for (i in 1:n)
-      if (WhatInds[i]){
-        points(A[i, 1], A[i, 2], col = ColorInd[i], cex=CexInd[i], pch = PchInd[i], ...)
-      }
-  
-  if (LabelInd)
-    for (i in 1:n)
-      if (WhatInds[i])
-        if (SmartLabels) 
-          textsmart(cbind(A[i, 1], A[i, 2]), CexPoints = CexInd[i], ColorPoints = ColorInd[i], ...)
-  else text(A[i, 1], A[i, 2], IndLabels[i], cex = CexInd[i], col = ColorInd[i], pos = LabelPos, ...)
+
   
   if ((x$Type == "FA") & (PlotUnitCircle)){
     Circle(1/x$Scale_Factor)
