@@ -2,7 +2,7 @@ plot.Supplementary.Variables <- function(x, F1=1, F2=2, xmin = -3, xmax = 3, ymi
                                          ValuesScale = "Original", mode="s", dp = 0, PredPoints=0, 
                                          ColorSupContVars="black", ColorSupBinVars="darkblue", ColorSupOrdVars="blue", 
                                          ModeSupContVars="s", ModeSupBinVars="s", 
-                                         ModeSupOrdVars="s", WhatSupBinVars=NULL, CexScale=0.5, ...){
+                                         ModeSupOrdVars="s", WhatSupBinVars=NULL, CexScale=0.5, ColCex=ColCex, ...){
   
 
    if (!is.null(x$ContSupVarsBiplot)){
