@@ -1,4 +1,4 @@
-summary.ContinuousBiplot <- function(object, latex=FALSE, ...) {
+summary.ContinuousBiplot <- function(object, SumInd=FALSE, latex=FALSE, ...) {
   if (object$Type=="PCA")
     cat(" ###### Biplot for Principal Components Analysis #######\n\n")
   if (object$Type=="FA")
@@ -41,17 +41,22 @@ summary.ContinuousBiplot <- function(object, latex=FALSE, ...) {
   }
   
   cat("\n\n RELATIVE CONTRIBUTIONS OF THE FACTOR TO THE ELEMENT\n")
-  cat("\n Row Contributions \n")
-  print(round(object$RowContributions, digits=2))
+  if (SumInd){
+    cat("\n Row Contributions \n")
+    print(round(object$RowContributions, digits=2))
+  }
+  
   cat("\n Column Contributions \n")
   print(round(object$ColContributions, digits=2))
   
+  if (SumInd){
+    cat("\n\n\n Qualities of representation of the rows (Cummulative contributions) \n")
+    if (is.null(object$CumRowContributions))
+      print(round(t(apply(object$RowContributions,1, cumsum)), digits=2))
+    else
+      print(round(object$CumRowContributions, digits=2))
+  }
 
-  cat("\n\n\n Qualities of representation of the rows (Cummulative contributions) \n")
-  if (is.null(object$CumRowContributions))
-    print(round(t(apply(object$RowContributions,1, cumsum)), digits=2))
-  else
-    print(round(object$CumRowContributions, digits=2))
   
   cat("\n\n\n Qualities of representation of the columns (Cummulative contributions) \n")
   if (is.null(object$CumColContributions))
@@ -63,13 +68,19 @@ summary.ContinuousBiplot <- function(object, latex=FALSE, ...) {
   
   if (latex){
     print(xtable(pp, caption="Explained Variance"))
-    print(xtable(round(object$RowContributions, digits=2), caption="Row Contributions Factor to element"))
+    
+    if (SumInd){
+      print(xtable(round(object$RowContributions, digits=2), caption="Row Contributions Factor to element"))
+    }
     print(xtable(round(object$ColContributions, digits=2), caption="Column Contributions Factor to element"))
     
-    if (is.null(object$CumRowContributions))
-      print(xtable(round(t(apply(object$RowContributions,1, cumsum)), digits=2), caption="Qualities of the rows"))
-    else
-      print(xtable(round(object$CumRowContributions, digits=2), caption="Qualities of the rows"))
+    if (SumInd){
+      if (is.null(object$CumRowContributions))
+        print(xtable(round(t(apply(object$RowContributions,1, cumsum)), digits=2), caption="Qualities of the rows"))
+      else
+        print(xtable(round(object$CumRowContributions, digits=2), caption="Qualities of the rows"))
+    }
+
     
     if (is.null(object$CumColContributions))
       print(xtable(round(t(apply(object$ColContributions,1, cumsum)), digits=2), caption="Qualities of the columns"))
